@@ -15,7 +15,7 @@ from nbconvert.exporters import Exporter
 from traitlets.tests.utils import check_help_all_output
 from ipython_genutils.testing import decorators as dec
 from testpath import tempdir
-from nose.tools import assert_raises, assert_in, assert_not_in
+import pytest
 
 #-----------------------------------------------------------------------------
 # Classes and functions
@@ -306,6 +306,25 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('empty.ipynb')
             assert not os.path.isfile('empty.nbconvert.ipynb')
             assert not os.path.isfile('empty.html')
+    
+    def test_no_prompt(self):
+        """
+        Verify that the notebook is converted in place
+        """
+        with self.create_temp_cwd(["notebook1.ipynb"]):
+            self.nbconvert('notebook1.ipynb --log-level 0 --no-prompt --to html')
+            assert os.path.isfile('notebook1.html')
+            with open("notebook1.html",'r') as f:
+                text = f.read()
+                assert "In&nbsp;[" not in text
+                assert "Out[" not in text
+            self.nbconvert('notebook1.ipynb --log-level 0 --to html')
+            assert os.path.isfile('notebook1.html')
+            with open("notebook1.html",'r') as f:
+                text2 = f.read()
+                print(text2)
+                assert "In&nbsp;[" in text2
+                assert "Out[" in text2
 
     def test_allow_errors(self):
         """
@@ -332,9 +351,20 @@ class TestNbConvertApp(TestsBase):
             assert '42' in output3
 
             # Executing the notebook should raise an exception if --allow-errors is not specified
-            with assert_raises(OSError):
+            with pytest.raises(OSError):
                 self.nbconvert('--execute --to markdown --stdout notebook3*.ipynb')
 
+    def test_errors_print_traceback(self):
+        """
+        Verify that the stderr output contains the traceback of the cell execution exception.
+        """
+        with self.create_temp_cwd(['notebook3_with_errors.ipynb']):
+            _, error_output = self.nbconvert('--execute --to markdown --stdout notebook3_with_errors.ipynb',
+                                             ignore_return_code=True)
+            assert 'print("Some text before the error")' in error_output
+            assert 'raise RuntimeError("This is a deliberate exception")' in error_output
+            assert 'RuntimeError: This is a deliberate exception' in error_output
+
     def test_fenced_code_blocks_markdown(self):
         """
         Verify that input cells use fenced code blocks with the language
@@ -361,8 +391,8 @@ class TestNbConvertApp(TestsBase):
             with io.open('notebook1.ipynb') as f:
                 notebook = f.read().encode()
                 output1, _ = self.nbconvert('--to markdown --stdin --stdout', stdin=notebook)
-            assert_not_in('```python', output1) # shouldn't have language
-            assert_in("```", output1) # but should have fenced blocks
+            assert '```python' not in output1 # shouldn't have language
+            assert "```" in output1 # but should have fenced blocks
 
     def test_convert_from_stdin(self):
         """
@@ -375,8 +405,8 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile("notebook.md") # default name for stdin input
             with io.open('notebook.md') as f:
                 output1 = f.read()
-                assert_not_in('```python', output1) # shouldn't have language
-                assert_in("```", output1) # but should have fenced blocks
+                assert '```python' not in output1 # shouldn't have language
+                assert "```" in output1 # but should have fenced blocks
 
     @dec.onlyif_cmds_exist('xelatex')
     @dec.onlyif_cmds_exist('pandoc')
@@ -411,8 +441,8 @@ class TestNbConvertApp(TestsBase):
             assert os.path.isfile('markdown_display_priority.md')
             with io.open('markdown_display_priority.md') as f:
                 markdown_output = f.read()
-                assert_in("markdown_display_priority_files/"
-                          "markdown_display_priority_0_1.png", markdown_output)
+                assert ("markdown_display_priority_files/"
+                        "markdown_display_priority_0_1.png") in markdown_output
 
     @dec.onlyif_cmds_exist('pandoc')
     def test_write_figures_to_custom_path(self):
